==> security-engine-starter-1.0-sources.jar: digital/nedra/commons/starter/security/engine/core/rest/ConfigurationRoleController.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.security.engine.core.rest;

import digital.nedra.commons.starter.security.engine.core.SecurityEngine;
import digital.nedra.commons.starter.security.engine.core.dto.AuthorityDto;
import digital.nedra.commons.starter.security.engine.core.dto.RoleAuthoritiesDto;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequiredArgsConstructor
public class ConfigurationRoleController {

  private final SecurityEngine securityEngine;

  @GetMapping("/api/admin/security/engine/roles/config")
  public ResponseEntity<List<RoleAuthoritiesDto>> getAllRolesAuthorities() {
    return ResponseEntity.ok(securityEngine.getAllRoleAuthorities());
  }

  @GetMapping("/api/admin/security/engine/authorities/config")
  public ResponseEntity<List<AuthorityDto>> getAllAuthoritiesAndRoles() {
    return ResponseEntity.ok(securityEngine.getAllAuthoritiesAndRoles());
  }
}

==> security-engine-starter-1.1.1-sources.jar: digital/nedra/commons/starter/security/engine/core/rest/ConfigurationRoleController.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.security.engine.core.rest;

import digital.nedra.commons.starter.security.engine.core.SecurityEngine;
import digital.nedra.commons.starter.security.engine.core.dto.AuthorityDto;
import digital.nedra.commons.starter.security.engine.core.dto.RoleAuthoritiesDto;
import java.util.List;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequiredArgsConstructor
@RequestMapping("/api/admin/security/engine")
public class ConfigurationRoleController {

  private final SecurityEngine securityEngine;

  @GetMapping("/roles/config")
  public ResponseEntity<List<RoleAuthoritiesDto>> getAllRolesAuthorities() {
    return ResponseEntity.ok(securityEngine.getAllRoleAuthorities());
  }

  @GetMapping("/authorities/config")
  public ResponseEntity<List<AuthorityDto>> getAllAuthoritiesAndRoles() {
    return ResponseEntity.ok(securityEngine.getAllAuthoritiesAndRoles());
  }
}
